
#line 3 "lex.swf5.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer swf5_create_buffer
#define yy_delete_buffer swf5_delete_buffer
#define yy_flex_debug swf5_flex_debug
#define yy_init_buffer swf5_init_buffer
#define yy_flush_buffer swf5_flush_buffer
#define yy_load_buffer_state swf5_load_buffer_state
#define yy_switch_to_buffer swf5_switch_to_buffer
#define yyin swf5in
#define yyleng swf5leng
#define yylex swf5lex
#define yylineno swf5lineno
#define yyout swf5out
#define yyrestart swf5restart
#define yytext swf5text
#define yywrap swf5wrap
#define yyalloc swf5alloc
#define yyrealloc swf5realloc
#define yyfree swf5free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE swf5restart(swf5in  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int swf5leng;

extern FILE *swf5in, *swf5out;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up swf5text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up swf5text again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via swf5restart()), so that the user can continue scanning by
	 * just pointing swf5in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when swf5text is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int swf5leng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow swf5wrap()'s to do buffer switches
 * instead of setting up a fresh swf5in.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void swf5restart (FILE *input_file  );
void swf5_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE swf5_create_buffer (FILE *file,int size  );
void swf5_delete_buffer (YY_BUFFER_STATE b  );
void swf5_flush_buffer (YY_BUFFER_STATE b  );
void swf5push_buffer_state (YY_BUFFER_STATE new_buffer  );
void swf5pop_buffer_state (void );

static void swf5ensure_buffer_stack (void );
static void swf5_load_buffer_state (void );
static void swf5_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER swf5_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE swf5_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE swf5_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE swf5_scan_bytes (yyconst char *bytes,int len  );

void *swf5alloc (yy_size_t  );
void *swf5realloc (void *,yy_size_t  );
void swf5free (void *  );

#define yy_new_buffer swf5_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        swf5ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            swf5_create_buffer(swf5in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        swf5ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            swf5_create_buffer(swf5in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *swf5in = (FILE *) 0, *swf5out = (FILE *) 0;

typedef int yy_state_type;

extern int swf5lineno;

int swf5lineno = 1;

extern char *swf5text;
#define yytext_ptr swf5text

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up swf5text.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	swf5leng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 166
#define YY_END_OF_BUFFER 167
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[650] =
    {   0,
        0,    0,    0,    0,  167,  165,  119,  164,  165,  152,
      165,  151,  146,  165,  153,  154,  149,  144,  159,  145,
      160,  150,    3,    3,  162,  142,  140,  143,  141,  161,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  155,  156,
      148,  157,  147,  158,  163,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      164,  125,    0,  115,  113,    0,  126,  132,    0,  116,
      114,    0,  128,  120,  130,  121,  131,  117,  118,  129,
        4,    2,    3,    0,  134,  122,  124,  123,  135,  112,

      112,  112,  112,  112,  112,  112,   19,  112,  112,  112,
      112,  112,  112,  112,  112,   17,   16,  112,  112,  112,
      112,  112,  112,  112,    0,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  133,  127,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,   16,
      112,  112,  112,  112,  112,  112,  112,  112,   63,  112,
      112,  112,  112,  112,  112,  112,  112,  112,    4,    1,
      137,  138,  136,   25,  112,  112,  112,   37,  112,  112,
      112,  112,  112,  112,  112,   15,  112,  112,  112,  112,
       35,  112,  112,   21,  112,  112,   36,  112,  112,  111,

      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,   20,  112,  112,   66,   62,  112,  112,   73,  112,
       55,  110,  112,  112,  109,   72,  112,  112,  112,  112,
      112,  112,  112,  112,  112,   21,   91,  112,   57,  112,
      112,  112,  112,  112,  112,  112,  112,  112,   20,   64,
      139,  112,  112,   13,  112,  112,  112,  112,  112,   11,
       26,  112,  112,  112,  112,  112,  112,  112,  112,  112,
        7,   42,  112,  112,  112,  112,  112,   43,  112,  112,
      112,  112,    5,  112,  112,   24,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,

      112,  112,  112,  112,  112,  112,  112,  112,  108,   58,
      112,  112,  112,  112,  112,  112,   43,  112,  112,  112,
       56,  112,    8,  112,  112,  112,  112,  112,  112,    6,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,   34,  112,
       18,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  104,  112,  103,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,   32,  112,  112,
       22,  112,  112,  112,   38,  112,  112,   31,  112,  112,

      112,  112,   29,  112,   23,  112,  112,   33,   12,  112,
       27,  105,  112,  112,   86,  112,   70,  112,  112,  112,
      112,  112,  112,  112,  112,   65,  112,   67,  112,  112,
       83,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,   33,  112,  112,  112,  112,   14,  112,  112,
      112,   39,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,    9,  112,   10,   30,  112,  112,

      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,   68,  112,  112,
      101,  112,   85,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,   99,   92,  112,  112,   84,  112,
       46,  112,   47,  112,   50,  112,   40,   41,  112,   48,
      112,  112,  112,  112,  112,  112,   74,   77,  112,   76,
      112,  112,   90,  112,   71,  112,   87,  112,   78,  112,
       48,  112,   79,  112,   98,  112,  112,   94,   82,  112,
       28,  112,  112,  112,   45,  112,  112,  112,  112,   61,
      112,   75,   89,  112,  112,  112,  112,  112,  112,   80,

      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
       95,  102,   69,   88,   59,  112,   96,   81,  112,  112,
      112,   52,  112,  112,  112,  106,  107,   60,  112,   93,
      112,  112,   49,  112,   44,   97,  112,  112,  112,  112,
      100,  112,  112,   54,  112,   51,  112,   53,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    2,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    1,    1,    7,    8,    9,   10,
       11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
       21,   21,   21,   21,   21,   22,   22,   23,   24,   25,
       26,   27,   28,    1,   29,   30,   31,   32,   33,   34,
       35,   36,   37,   38,   39,   40,   41,   42,   43,   44,
       45,   46,   47,   48,   49,   50,   51,   52,   53,   54,
       55,   56,   57,   58,   54,    1,   59,   60,   61,   62,

       63,   64,   65,   66,   67,   68,   69,   70,   71,   72,
       73,   74,   75,   76,   77,   78,   79,   80,   81,   82,
       83,   54,   84,   85,   86,   87,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[88] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    2,    2,    2,
        2,    2,    1,    1,    1,    1,    1,    1,    2,    2,
        2,    2,    2,    2,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    1,    1,    1,    1,    2,    2,
        2,    2,    2,    2,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    1,    1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[654] =
    {   0,
        0,    0,   59,    0,  322, 1377, 1377, 1377,  317,  275,
       92, 1377,   89,  101, 1377, 1377,  259,   99, 1377,   90,
     1377,  111,  124,  131, 1377, 1377,   82,  212,   87, 1377,
       87,   89,  125,  123,  119,  131,  130,    0,  128,  134,
      122,  112,  135,  185,  176,  169,  154,  180, 1377, 1377,
     1377, 1377,  152, 1377, 1377,  187,  174,  192,  223,  228,
      190,  227,  234,  232,  246,  234,  272,  280,  212,  233,
     1377, 1377,  176,  237, 1377,  228, 1377, 1377,  227,  279,
     1377,  223, 1377, 1377, 1377, 1377, 1377, 1377, 1377, 1377,
      318,  334,  344,    0,  161, 1377, 1377, 1377,  168,    0,

      243,  254,  327,  248,  285,  307,    0,  305,  321,  340,
      330,  326,  331,  327,  328,    0,  333,  336,  353,  332,
      345,  354,  358,  355,  371,  352,  378,  347,  358,  377,
      372,  385,  392,  378,  377,  390,  380, 1377, 1377,  397,
      398,  403,  393,  404,  384,  398,  429,  394,  397,  445,
      437,  448,  454,  437,  440,  435,  433,  456,  457,  451,
      443,  448,  463,  492,  472,  500,  457,  458,  521,    0,
     1377, 1377,  112,    0,  507,  504,  512,    0,  515,  518,
      515,  509,  517,  512,  506,    0,  523,  507,  514,  510,
        0,  525,  529,    0,  514,  524,    0,  516,  520,  583,

      549,  546,  546,  548,  553,  551,  558,  572,  577,  576,
      577,    0,  572,  577,    0,    0,  572,  575,    0,  579,
      577,    0,  577,  591,  581,    0,  573,  576,  587,  596,
      600,  588,  586,  592,  601,  637,    0,  640,    0,  607,
      620,  626,  623,  612,  624,  638,  634,  634,  650,    0,
     1377,  645,  655,    0,  661,  654,  643,  645,  657,    0,
        0,  662,  653,  672,  669,  682,  688,  670,  685,  693,
        0,    0,  694,  686,  680,  686,  704,  687,  688,  706,
      698,  707,    0,  698,  709,    0,  712,  710,  717,  717,
      712,  720,  725,  726,  713,  744,  730,  735,  746,  756,

      747,  751,  757,  745,  759,  761,  749,  762,    0,    0,
      763,  764,  769,  771,  753,  754,  782,  761,  756,  763,
        0,  765,    0,  765,  764,  771,  775,  788,  804,    0,
      799,  796,  798,  800,  805,  812,  806,  821,  806,  807,
      813,  822,  814,  811,  815,  814,  825,  829,    0,  829,
        0,  828,  823,  837,  838,  827,  827,  834,  835,  843,
      865,  860,  868,    0,  863,    0,  859,  864,  864,  877,
      861,  865,  881,  865,  868,  875,  882,  872,  874,  883,
      889,  876,  889,  884,  902,  883,  904,    0,  885,  887,
        0,  912,  906,  922,  108,  927,  926,    0,  908,  920,

      938,  939,    0,  928,    0,  935,  923,    0,    0,  928,
        0,  945,  933,  928,    0,  948,    0,  948,  943,  935,
      945,  955,  949,  942,  943,    0,  952,    0,  964,  947,
        0,  966,  954,  979,  978,  981,  980,  985,  989,  981,
      999,  996,  993, 1001, 1004,  993, 1002,    0,  989,  996,
      994,    0, 1000, 1009, 1006, 1007, 1008, 1009, 1008, 1019,
     1011, 1005, 1015, 1027, 1038, 1039, 1028, 1044, 1049, 1057,
     1054, 1046, 1060, 1054, 1046, 1040, 1054, 1047, 1056, 1049,
     1065, 1053, 1068, 1073, 1070, 1074, 1081, 1076, 1067, 1080,
     1072, 1067, 1081, 1096,    0, 1102,    0,    0, 1103, 1094,

     1105, 1117, 1114, 1115, 1099, 1102, 1120, 1124, 1103, 1107,
     1108, 1114, 1125, 1114, 1131, 1109, 1132,    0, 1122, 1123,
        0, 1133,    0, 1124, 1136, 1126, 1138, 1129, 1133, 1141,
     1165, 1148, 1161, 1163,    0,    0, 1165, 1171,    0, 1161,
        0, 1168,    0, 1176, 1171, 1184,    0,    0, 1178,    0,
     1169, 1177, 1189, 1174, 1184, 1190,    0,    0, 1183,    0,
     1176, 1197,    0, 1188,    0, 1202,    0, 1203,    0, 1200,
     1201, 1195,    0, 1193,    0, 1214, 1208,    0,    0, 1213,
        0, 1208, 1218, 1233,    0, 1230, 1215, 1220, 1227,    0,
     1239,    0,    0, 1238, 1232, 1233, 1230, 1225, 1245,   97,

     1232, 1233, 1232, 1242, 1251, 1258, 1242, 1244, 1259, 1251,
        0,    0,    0,    0,    0, 1250,    0,    0, 1259, 1265,
     1272,    0, 1268, 1276, 1264,    0,    0,    0, 1272,    0,
     1297, 1294, 1286, 1292,    0,    0, 1288, 1301, 1284, 1290,
        0, 1295, 1295,    0, 1300,    0, 1294,    0, 1377, 1368,
     1371, 1373,   91
    } ;

static yyconst flex_int16_t yy_def[654] =
    {   0,
      649,    1,    1,    3,  649,  649,  649,  649,  649,  649,
      650,  649,  649,  651,  649,  649,  649,  649,  649,  649,
      649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  649,  649,
      649,  649,  649,  649,  649,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      649,  649,  650,  650,  649,  650,  649,  649,  651,  651,
      649,  651,  649,  649,  649,  649,  649,  649,  649,  649,
      649,  649,  649,  653,  649,  649,  649,  649,  649,  652,

      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  649,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  649,  649,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  649,  653,
      649,  649,  649,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  649,

      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      649,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,

      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,

      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,

      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,

      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,    0,  649,
      649,  649,  649
    } ;

static yyconst flex_int16_t yy_nxt[1465] =
    {   0,
        6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
       16,   17,   18,   19,   20,   21,   22,   23,   24,   24,
       24,   24,   25,   26,   27,   28,   29,   30,   31,   32,
       33,   34,   35,   36,   37,   38,   39,   38,   38,   40,
       38,   41,   42,   43,   38,   44,   45,   46,   38,   47,
       48,   38,   38,   38,   49,    6,   50,   51,   31,   32,
       33,   34,   35,   36,   37,   38,   39,   38,   38,   40,
       38,   41,   42,   43,   38,   44,   45,   46,   38,   47,
       48,   38,   38,   52,   53,   54,   55,   56,   57,   58,
       59,   60,  170,   61,   74,   62,   77,   75,   63,   64,

       65,   66,   67,   80,   86,   68,   95,   96,   69,   81,
       70,   84,   98,   99,   78,   87,  618,   56,   57,   58,
       59,   60,   88,   61,   85,   62,  452,   89,   63,   64,
       65,   66,   67,  101,  102,   68,   90,  251,   69,   91,
       70,   92,   92,   92,   92,   93,   91,   76,   93,   93,
       93,   93,   93,  103,  120,  106,   82,  122,  109,  111,
      104,  116,  114,  101,  102,  107,  118,  105,  110,  117,
      121,  108,  115,  112,  123,   94,  119,  138,   74,  113,
      124,   75,  135,  103,  120,  106,  171,  122,  109,  111,
      104,  116,  114,  172,  173,  107,  118,  105,  110,  117,

      121,  108,  115,  112,  123,   94,  119,  125,  128,  113,
      124,  132,  135,  126,  133,  136,  137,  127,  140,  142,
      143,  134,  149,  129,  130,  649,  131,  104,  141,   80,
      649,   76,  115,  101,  105,   81,  139,   97,  128,   74,
      167,  132,   75,  126,  133,  136,  137,  127,  140,  142,
      143,  134,  149,  129,  130,  144,  131,  104,  141,  145,
      116,  153,  115,  101,  105,  107,  151,  109,  150,  147,
      167,  146,  148,  158,  154,  168,  152,  110,  156,  159,
      155,   80,   82,  174,   83,  144,  175,   81,  157,  145,
      116,  153,   76,  178,  121,  107,  151,  109,  150,  147,

       72,  146,  148,  158,  154,  168,  152,  110,  156,  159,
      155,  123,  162,  174,  160,  163,  175,  124,  157,   71,
      161,  649,  649,  178,  121,  649,  179,  164,  165,  649,
      166,  649,  649,  649,   82,  169,  169,  169,  169,  169,
      180,  123,  162,  649,  160,  163,  181,  124,  182,   91,
      161,   92,   92,   92,   92,   93,  179,  164,  165,   91,
      166,   93,   93,   93,   93,   93,  176,  183,  184,  185,
      180,  186,  187,  177,  188,  189,  181,  192,  182,  190,
      191,  193,  194,  195,  196,  197,  198,  199,  200,  200,
      200,  200,  200,  201,  204,  649,  176,  183,  184,  185,

      205,  186,  187,  177,  188,  189,  206,  192,  207,  190,
      191,  193,  194,  195,  196,  197,  198,  199,  202,  208,
      209,  211,  212,  201,  204,  203,  213,  214,  215,  216,
      205,  217,  218,  220,  219,  175,  206,  180,  207,  177,
      210,  221,  224,  181,  225,  649,  649,  649,  202,  208,
      209,  211,  212,  649,  649,  203,  213,  214,  215,  216,
      222,  217,  218,  220,  219,  175,  649,  180,  234,  177,
      210,  221,  224,  181,  225,  226,  193,  223,  192,  235,
      237,  227,  229,  228,  230,  236,  195,  238,  197,  241,
      222,  190,  191,  231,  239,  242,  232,  240,  234,  243,

      233,  247,  249,  250,  649,  226,  193,  223,  192,  235,
      237,  227,  229,  228,  230,  236,  195,  238,  197,  241,
      244,  190,  191,  231,  239,  242,  232,  240,  248,  243,
      233,  247,  249,  250,  245,  252,  207,  246,  169,  169,
      169,  169,  169,  253,  254,  255,  257,  258,  259,  260,
      244,  261,  262,  263,  264,  265,  266,  267,  248,  268,
      269,  270,  256,  271,  245,  252,  207,  246,  272,  273,
      649,  649,  649,  253,  254,  255,  257,  258,  259,  260,
      274,  261,  262,  263,  264,  265,  266,  267,  275,  268,
      269,  270,  256,  271,  276,  277,  278,  279,  272,  273,

      200,  200,  200,  200,  200,  280,  281,  282,  283,  284,
      274,  285,  286,  287,  288,  289,  259,  290,  275,  291,
      294,  292,  295,  296,  276,  277,  278,  279,  264,  265,
      293,  297,  298,  299,  300,  280,  281,  282,  283,  284,
      301,  285,  286,  287,  288,  289,  259,  290,  302,  291,
      294,  292,  295,  296,  309,  310,  315,  316,  264,  265,
      293,  297,  298,  299,  300,  303,  311,  317,  306,  304,
      301,  312,  307,  313,  318,  314,  305,  321,  302,  308,
      319,  320,  322,  323,  309,  310,  315,  316,  324,  325,
      326,  327,  328,  329,  330,  303,  311,  317,  306,  304,

      331,  312,  307,  313,  318,  314,  305,  321,  332,  308,
      319,  320,  322,  323,  333,  334,  335,  336,  324,  325,
      326,  327,  328,  329,  330,  337,  339,  340,  341,  342,
      331,  343,  344,  345,  338,  346,  347,  348,  332,  349,
      350,  351,  352,  353,  333,  334,  335,  336,  355,  356,
      354,  357,  358,  359,  360,  337,  339,  340,  341,  342,
      362,  343,  344,  345,  338,  346,  347,  348,  361,  349,
      350,  351,  352,  353,  363,  364,  365,  366,  355,  356,
      354,  357,  358,  359,  360,  367,  368,  369,  370,  371,
      362,  372,  373,  374,  375,  376,  377,  378,  361,  379,

      380,  381,  383,  384,  363,  364,  365,  366,  385,  386,
      387,  388,  389,  382,  390,  367,  368,  369,  370,  371,
      391,  372,  373,  374,  375,  376,  377,  378,  345,  379,
      380,  381,  383,  384,  392,  393,  394,  395,  385,  386,
      387,  388,  389,  382,  390,  396,  397,  398,  399,  400,
      391,  401,  402,  403,  404,  405,  406,  407,  345,  408,
      409,  410,  411,  412,  392,  393,  394,  395,  387,  414,
      415,  413,  416,  417,  418,  396,  397,  398,  399,  400,
      419,  401,  402,  403,  404,  405,  406,  407,  420,  408,
      409,  410,  411,  412,  421,  422,  423,  424,  387,  414,

      415,  413,  416,  417,  418,  425,  426,  427,  428,  429,
      419,  430,  431,  432,  433,  434,  435,  436,  420,  437,
      440,  441,  438,  442,  421,  422,  423,  424,  439,  443,
      444,  445,  446,  447,  448,  425,  426,  427,  428,  429,
      449,  430,  431,  432,  433,  434,  435,  436,  450,  437,
      440,  441,  438,  442,  451,  453,  454,  455,  439,  443,
      444,  445,  446,  447,  448,  456,  457,  458,  459,  460,
      449,  461,  462,  463,  465,  466,  467,  468,  450,  469,
      470,  464,  471,  472,  451,  453,  454,  455,  473,  474,
      475,  476,  477,  478,  479,  456,  457,  458,  459,  460,

      480,  461,  462,  463,  465,  466,  467,  468,  481,  469,
      470,  464,  471,  472,  482,  483,  484,  485,  473,  474,
      475,  476,  477,  478,  479,  486,  487,  488,  489,  491,
      480,  492,  493,  494,  495,  490,  496,  497,  481,  498,
      499,  500,  501,  502,  482,  483,  484,  485,  503,  504,
      505,  506,  507,  508,  509,  486,  487,  488,  489,  491,
      510,  492,  493,  494,  495,  490,  496,  497,  511,  498,
      499,  500,  501,  502,  512,  513,  514,  515,  503,  504,
      505,  506,  507,  508,  509,  516,  517,  518,  519,  521,
      510,  522,  523,  524,  525,  526,  527,  528,  511,  529,

      530,  531,  520,  532,  512,  513,  514,  515,  533,  534,
      535,  536,  537,  538,  539,  516,  517,  518,  519,  521,
      540,  522,  523,  524,  525,  526,  527,  528,  541,  529,
      530,  531,  520,  532,  542,  543,  544,  545,  533,  534,
      535,  536,  537,  538,  539,  546,  547,  548,  549,  550,
      540,  551,  552,  553,  554,  555,  556,  557,  541,  558,
      559,  560,  561,  562,  542,  543,  544,  545,  563,  564,
      565,  566,  567,  568,  569,  546,  547,  548,  549,  550,
      570,  551,  552,  553,  554,  555,  556,  557,  571,  558,
      559,  560,  561,  562,  572,  573,  574,  575,  563,  564,

      565,  566,  567,  568,  569,  578,  576,  579,  580,  581,
      570,  577,  582,  583,  584,  585,  586,  587,  571,  588,
      589,  590,  591,  592,  572,  573,  574,  575,  593,  594,
      595,  596,  597,  598,  599,  578,  576,  579,  580,  581,
      600,  577,  582,  583,  584,  585,  586,  587,  601,  588,
      589,  590,  591,  592,  602,  603,  604,  605,  593,  594,
      595,  596,  597,  598,  599,  606,  607,  608,  609,  610,
      600,  611,  612,  613,  614,  615,  616,  617,  601,  619,
      620,  621,  622,  623,  602,  603,  604,  605,  624,  625,
      626,  627,  628,  629,  630,  606,  607,  608,  609,  610,

      631,  611,  612,  613,  614,  615,  616,  617,  632,  619,
      620,  621,  622,  623,  633,  634,  635,  636,  624,  625,
      626,  627,  628,  629,  630,  637,  638,  639,  640,  641,
      631,  642,  643,  644,  645,  646,  647,  648,  632,  649,
      649,  649,  649,  649,  633,  634,  635,  636,  649,  649,
      649,  649,  649,  649,  649,  637,  638,  639,  640,  641,
      649,  642,  643,  644,  645,  646,  647,  648,   73,   73,
       73,   79,   79,   79,  100,  100,    5,  649,  649,  649,
      649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
      649,  649,  649,  649,  649,  649,  649,  649,  649,  649,

      649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
      649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
      649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
      649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
      649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
      649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
      649,  649,  649,  649
    } ;

static yyconst flex_int16_t yy_chk[1465] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    3,    3,    3,
        3,    3,  653,    3,   11,    3,   13,   11,    3,    3,

        3,    3,    3,   14,   20,    3,   27,   27,    3,   14,
        3,   18,   29,   29,   13,   20,  600,    3,    3,    3,
        3,    3,   22,    3,   18,    3,  395,   22,    3,    3,
        3,    3,    3,   31,   32,    3,   22,  173,    3,   23,
        3,   23,   23,   23,   23,   23,   24,   11,   24,   24,
       24,   24,   24,   33,   41,   34,   14,   42,   35,   36,
       33,   39,   37,   31,   32,   34,   40,   33,   35,   39,
       41,   34,   37,   36,   43,   23,   40,   53,   73,   36,
       43,   73,   47,   33,   41,   34,   95,   42,   35,   36,
       33,   39,   37,   99,   99,   34,   40,   33,   35,   39,

       41,   34,   37,   36,   43,   23,   40,   44,   45,   36,
       43,   46,   47,   44,   46,   48,   48,   44,   56,   57,
       58,   46,   61,   45,   45,   82,   45,   58,   56,   79,
       76,   73,   61,   56,   58,   79,   53,   28,   45,   74,
       69,   46,   74,   44,   46,   48,   48,   44,   56,   57,
       58,   46,   61,   45,   45,   59,   45,   58,   56,   59,
       62,   64,   61,   56,   58,   59,   63,   60,   62,   60,
       69,   59,   60,   66,   64,   70,   63,   60,   65,   66,
       64,   80,   79,  101,   17,   59,  102,   80,   65,   59,
       62,   64,   74,  104,   65,   59,   63,   60,   62,   60,

       10,   59,   60,   66,   64,   70,   63,   60,   65,   66,
       64,   67,   68,  101,   67,   68,  102,   67,   65,    9,
       67,    5,    0,  104,   65,    0,  105,   68,   68,    0,
       68,    0,    0,    0,   80,   91,   91,   91,   91,   91,
      106,   67,   68,    0,   67,   68,  106,   67,  108,   92,
       67,   92,   92,   92,   92,   92,  105,   68,   68,   93,
       68,   93,   93,   93,   93,   93,  103,  109,  110,  111,
      106,  112,  113,  103,  114,  115,  106,  118,  108,  117,
      117,  119,  120,  120,  121,  122,  123,  124,  125,  125,
      125,  125,  125,  126,  128,    0,  103,  109,  110,  111,

      129,  112,  113,  103,  114,  115,  130,  118,  131,  117,
      117,  119,  120,  120,  121,  122,  123,  124,  127,  132,
      133,  134,  135,  126,  128,  127,  136,  137,  140,  141,
      129,  142,  143,  145,  144,  142,  130,  144,  131,  143,
      133,  146,  148,  144,  149,    0,    0,    0,  127,  132,
      133,  134,  135,    0,    0,  127,  136,  137,  140,  141,
      147,  142,  143,  145,  144,  142,    0,  144,  154,  143,
      133,  146,  148,  144,  149,  150,  152,  147,  151,  155,
      157,  150,  152,  151,  153,  156,  156,  158,  159,  161,
      147,  150,  150,  153,  160,  162,  153,  160,  154,  163,

      153,  165,  167,  168,    0,  150,  152,  147,  151,  155,
      157,  150,  152,  151,  153,  156,  156,  158,  159,  161,
      164,  150,  150,  153,  160,  162,  153,  160,  166,  163,
      153,  165,  167,  168,  164,  175,  166,  164,  169,  169,
      169,  169,  169,  176,  177,  179,  180,  181,  182,  183,
      164,  184,  185,  187,  188,  188,  189,  190,  166,  192,
      193,  195,  179,  196,  164,  175,  166,  164,  198,  199,
        0,    0,    0,  176,  177,  179,  180,  181,  182,  183,
      201,  184,  185,  187,  188,  188,  189,  190,  202,  192,
      193,  195,  179,  196,  203,  204,  205,  206,  198,  199,

      200,  200,  200,  200,  200,  207,  208,  209,  210,  211,
      201,  213,  214,  217,  218,  220,  221,  223,  202,  224,
      227,  225,  228,  229,  203,  204,  205,  206,  225,  225,
      225,  230,  231,  232,  233,  207,  208,  209,  210,  211,
      234,  213,  214,  217,  218,  220,  221,  223,  235,  224,
      227,  225,  228,  229,  240,  241,  243,  244,  225,  225,
      225,  230,  231,  232,  233,  236,  242,  245,  238,  236,
      234,  242,  238,  242,  246,  242,  236,  248,  235,  238,
      247,  247,  249,  252,  240,  241,  243,  244,  253,  255,
      256,  257,  258,  259,  262,  236,  242,  245,  238,  236,

      263,  242,  238,  242,  246,  242,  236,  248,  264,  238,
      247,  247,  249,  252,  265,  266,  267,  268,  253,  255,
      256,  257,  258,  259,  262,  269,  270,  273,  274,  275,
      263,  276,  277,  278,  269,  279,  280,  281,  264,  282,
      284,  285,  287,  288,  265,  266,  267,  268,  289,  290,
      288,  291,  292,  293,  294,  269,  270,  273,  274,  275,
      295,  276,  277,  278,  269,  279,  280,  281,  294,  282,
      284,  285,  287,  288,  296,  297,  298,  299,  289,  290,
      288,  291,  292,  293,  294,  300,  301,  302,  303,  304,
      295,  305,  306,  307,  308,  311,  312,  313,  294,  314,

      315,  316,  318,  319,  296,  297,  298,  299,  320,  322,
      324,  325,  326,  317,  327,  300,  301,  302,  303,  304,
      328,  305,  306,  307,  308,  311,  312,  313,  317,  314,
      315,  316,  318,  319,  329,  331,  332,  333,  320,  322,
      324,  325,  326,  317,  327,  334,  335,  336,  337,  338,
      328,  339,  340,  341,  342,  343,  344,  345,  317,  346,
      347,  348,  350,  352,  329,  331,  332,  333,  353,  354,
      355,  353,  356,  357,  358,  334,  335,  336,  337,  338,
      359,  339,  340,  341,  342,  343,  344,  345,  360,  346,
      347,  348,  350,  352,  361,  362,  363,  365,  353,  354,

      355,  353,  356,  357,  358,  367,  368,  369,  370,  371,
      359,  372,  373,  374,  375,  376,  377,  378,  360,  379,
      381,  382,  380,  383,  361,  362,  363,  365,  380,  384,
      385,  386,  387,  389,  390,  367,  368,  369,  370,  371,
      392,  372,  373,  374,  375,  376,  377,  378,  393,  379,
      381,  382,  380,  383,  394,  396,  397,  399,  380,  384,
      385,  386,  387,  389,  390,  400,  401,  402,  404,  406,
      392,  407,  410,  412,  413,  414,  416,  418,  393,  419,
      420,  412,  421,  422,  394,  396,  397,  399,  423,  424,
      425,  427,  429,  430,  432,  400,  401,  402,  404,  406,

      433,  407,  410,  412,  413,  414,  416,  418,  434,  419,
      420,  412,  421,  422,  435,  436,  437,  438,  423,  424,
      425,  427,  429,  430,  432,  439,  440,  441,  442,  443,
      433,  444,  445,  446,  447,  442,  449,  450,  434,  451,
      453,  454,  455,  456,  435,  436,  437,  438,  457,  458,
      459,  460,  461,  462,  463,  439,  440,  441,  442,  443,
      464,  444,  445,  446,  447,  442,  449,  450,  465,  451,
      453,  454,  455,  456,  466,  467,  468,  469,  457,  458,
      459,  460,  461,  462,  463,  470,  471,  472,  473,  474,
      464,  475,  476,  477,  478,  479,  480,  481,  465,  482,

      483,  484,  473,  485,  466,  467,  468,  469,  486,  487,
      488,  489,  490,  491,  492,  470,  471,  472,  473,  474,
      493,  475,  476,  477,  478,  479,  480,  481,  494,  482,
      483,  484,  473,  485,  496,  499,  500,  501,  486,  487,
      488,  489,  490,  491,  492,  502,  503,  504,  505,  506,
      493,  507,  508,  509,  510,  511,  512,  513,  494,  514,
      515,  516,  517,  519,  496,  499,  500,  501,  520,  522,
      524,  525,  526,  527,  528,  502,  503,  504,  505,  506,
      529,  507,  508,  509,  510,  511,  512,  513,  530,  514,
      515,  516,  517,  519,  531,  532,  533,  534,  520,  522,

      524,  525,  526,  527,  528,  538,  537,  540,  542,  544,
      529,  537,  545,  546,  549,  551,  552,  553,  530,  554,
      555,  556,  559,  561,  531,  532,  533,  534,  562,  564,
      566,  568,  570,  571,  572,  538,  537,  540,  542,  544,
      574,  537,  545,  546,  549,  551,  552,  553,  576,  554,
      555,  556,  559,  561,  577,  580,  582,  583,  562,  564,
      566,  568,  570,  571,  572,  584,  586,  587,  588,  589,
      574,  591,  594,  595,  596,  597,  598,  599,  576,  601,
      602,  603,  604,  605,  577,  580,  582,  583,  606,  607,
      608,  609,  610,  616,  619,  584,  586,  587,  588,  589,

      620,  591,  594,  595,  596,  597,  598,  599,  621,  601,
      602,  603,  604,  605,  623,  624,  625,  629,  606,  607,
      608,  609,  610,  616,  619,  631,  632,  633,  634,  637,
      620,  638,  639,  640,  642,  643,  645,  647,  621,    0,
        0,    0,    0,    0,  623,  624,  625,  629,    0,    0,
        0,    0,    0,    0,    0,  631,  632,  633,  634,  637,
        0,  638,  639,  640,  642,  643,  645,  647,  650,  650,
      650,  651,  651,  651,  652,  652,  649,  649,  649,  649,
      649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
      649,  649,  649,  649,  649,  649,  649,  649,  649,  649,

      649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
      649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
      649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
      649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
      649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
      649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
      649,  649,  649,  649
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int swf5_flex_debug;
int swf5_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *swf5text;
#line 1 "swf5compiler.flex"
#line 2 "swf5compiler.flex"

#include <math.h>
#include <string.h>

#include "compile.h"
#include "action.h"
#include "blocks/error.h"
#include "swf5compiler.tab.h" /* defines token types */

static int swf5debug;

static const char *lexBuffer = NULL;
static int lexBufferLen = 0;

static int  sLineNumber = 0;
static char szLine[1024];
static char msgbufs[2][1024] = { {0}, {0} }, *msgline = {0};
static int  column = 0;

static void comment();
static void comment1();
static void count();
static void countline();
static void warning(char *msg);

#define YY_INPUT(buf,result,max_size) result=lexBufferInput(buf, max_size)

/* thanks to the prolific and brilliant Raff: */
static int lexBufferInput(char *buf, int max_size)
{
  int l = lexBufferLen > max_size ? max_size : lexBufferLen;

  if (lexBufferLen <= 0)
    return YY_NULL;

  memcpy(buf, lexBuffer, l);
  lexBuffer += l;
  lexBufferLen -= l;
  return l;
}

        /* very inefficient method of unescaping strings */
static void unescape(char *buf)
{
  char *p, *n;

  n = p = buf;
  while(*p) {
    if(*p == '\\') {
        switch(p[1])
        {
        case 'b' : *n++ = '\b'; break;
        case 'f' : *n++ = '\f'; break;
        case 'n' : *n++ = '\n'; break;
        case 'r' : *n++ = '\r'; break;
        case 't' : *n++ = '\t'; break;
        case 'x' :
        case 'u' : warning("unsupported escape sequence");
        }
        p+=2;
    } else {
        *n++ = *p++;
    }
  }
  *n = 0;
}

void swf5ParseInit(const char *script, int debug)
{
  checkByteOrder();
  swf5restart(NULL);

  swf5debug = debug;

  lexBuffer = script;
  lexBufferLen = strlen(script);
  sLineNumber = 0;
  column = 0;
  msgline = msgbufs[0];
}


#line 88 "swf5compiler.flex"
 // forward declaration needed by the following function
#ifndef YY_PROTO
#ifdef YY_USE_PROTOS
#define YY_PROTO(proto) proto
#else
#define YY_PROTO(proto) ()
#endif
#endif
 static void yyunput YY_PROTO(( int c, char *buf_ptr ));

 void do_unput5(const char c) { unput(c); }
#line 1103 "lex.swf5.c"

#define INITIAL 0
#define asm 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int swf5lex_destroy (void );

int swf5get_debug (void );

void swf5set_debug (int debug_flag  );

YY_EXTRA_TYPE swf5get_extra (void );

void swf5set_extra (YY_EXTRA_TYPE user_defined  );

FILE *swf5get_in (void );

void swf5set_in  (FILE * in_str  );

FILE *swf5get_out (void );

void swf5set_out  (FILE * out_str  );

int swf5get_leng (void );

char *swf5get_text (void );

int swf5get_lineno (void );

void swf5set_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int swf5wrap (void );
#else
extern int swf5wrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( swf5text, swf5leng, 1, swf5out )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( swf5in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( swf5in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, swf5in))==0 && ferror(swf5in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(swf5in); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int swf5lex (void);

#define YY_DECL int swf5lex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after swf5text and swf5leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 104 "swf5compiler.flex"


#line 1289 "lex.swf5.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! swf5in )
			swf5in = stdin;

		if ( ! swf5out )
			swf5out = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			swf5ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				swf5_create_buffer(swf5in,YY_BUF_SIZE );
		}

		swf5_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of swf5text. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 650 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1377 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 106 "swf5compiler.flex"
{ count();	swf5lval.intVal = strtoul(swf5text, NULL, 0);
					return INTEGER;		}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 108 "swf5compiler.flex"
{ count();	swf5lval.intVal = strtoul(swf5text, NULL, 0);
					return INTEGER;		}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 110 "swf5compiler.flex"
{ count();	swf5lval.intVal = atoi(swf5text);
					return INTEGER;		}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 112 "swf5compiler.flex"
{ count();	swf5lval.doubleVal = atof(swf5text);
					return DOUBLE; 		}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 114 "swf5compiler.flex"
{ count();	swf5lval.intVal = 1;
					return BOOLEAN;		}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 116 "swf5compiler.flex"
{ count();	swf5lval.intVal = 0;
					return BOOLEAN;		}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 118 "swf5compiler.flex"
{ count();	return NULLVAL;		}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 119 "swf5compiler.flex"
{ count();	return BREAK;		}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 120 "swf5compiler.flex"
{ count();	return CONTINUE;	}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 121 "swf5compiler.flex"
{ count();	return FUNCTION;	}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 122 "swf5compiler.flex"
{ count();	return ELSE;		}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 123 "swf5compiler.flex"
{ count();	return SWITCH;		}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 124 "swf5compiler.flex"
{ count();	return CASE;		}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 125 "swf5compiler.flex"
{ count();	return DEFAULT;		}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 126 "swf5compiler.flex"
{ count();	return FOR;		}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 127 "swf5compiler.flex"
{ count();	return IN;		}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 128 "swf5compiler.flex"
{ count();	return IF;		}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 129 "swf5compiler.flex"
{ count();	return WHILE;		}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 130 "swf5compiler.flex"
{ count();	return DO;		}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 131 "swf5compiler.flex"
{ count();	return VAR;		}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 132 "swf5compiler.flex"
{ count();	return NEW;		}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 133 "swf5compiler.flex"
{ count();	return DELETE;		}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 134 "swf5compiler.flex"
{ count();	return RETURN;		}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 135 "swf5compiler.flex"
{ count();	return WITH;		}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 136 "swf5compiler.flex"
{ count();	BEGIN(asm); return ASM;		}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 137 "swf5compiler.flex"
{ count();	return EVAL;		}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 138 "swf5compiler.flex"
{ count();	return TYPEOF; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 139 "swf5compiler.flex"
{ count();	return INSTANCEOF; }
	YY_BREAK
/* legacy functions */
case 29:
YY_RULE_SETUP
#line 142 "swf5compiler.flex"
{ count();	return RANDOM;	}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 143 "swf5compiler.flex"
{ count();	return GETTIMER;	}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 144 "swf5compiler.flex"
{ count();	return LENGTH;	}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 145 "swf5compiler.flex"
{ count();	return CONCAT;	}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 146 "swf5compiler.flex"
{ count();	return SUBSTR;	}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 147 "swf5compiler.flex"
{ count();	return TRACE;	}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 148 "swf5compiler.flex"
{ count();	return INT;	}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 149 "swf5compiler.flex"
{ count();	return ORD;	}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 150 "swf5compiler.flex"
{ count();	return CHR;	}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 151 "swf5compiler.flex"
{ count();	return GETURL;	}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 152 "swf5compiler.flex"
{ count();	return GETURL1;	}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 153 "swf5compiler.flex"
{ count();	return NEXTFRAME;	}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 154 "swf5compiler.flex"
{ count();	return PREVFRAME;	}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 155 "swf5compiler.flex"
{ count();	return PLAY;		}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 156 "swf5compiler.flex"
{ count();	return STOP;		}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 157 "swf5compiler.flex"
{ count();	return TOGGLEQUALITY;	}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 158 "swf5compiler.flex"
{ count();	return STOPSOUNDS;	}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 159 "swf5compiler.flex"
{ count();	return CALLFRAME;	}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 160 "swf5compiler.flex"
{ count();	return GOTOFRAME;	}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 161 "swf5compiler.flex"
{ count();	return SETTARGET;	}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 162 "swf5compiler.flex"
{ count();	return LOADVARIABLES;	}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 163 "swf5compiler.flex"
{ count();	return LOADMOVIE;	}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 164 "swf5compiler.flex"
{ count();	return LOADVARIABLESNUM;	}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 165 "swf5compiler.flex"
{ count();	return LOADMOVIENUM;	}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 166 "swf5compiler.flex"
{ count();	return DUPLICATEMOVIECLIP; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 167 "swf5compiler.flex"
{ count();	return REMOVEMOVIECLIP; }
	YY_BREAK
/* assembler ops */

case 55:
YY_RULE_SETUP
#line 171 "swf5compiler.flex"
{ count();	return DUP; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 172 "swf5compiler.flex"
{ count();	return SWAP; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 173 "swf5compiler.flex"
{ count();	return POP; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 174 "swf5compiler.flex"
{ count();	return PUSH; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 175 "swf5compiler.flex"
{ count();	return SETREGISTER; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 176 "swf5compiler.flex"
{ count();	return CALLFUNCTION; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 177 "swf5compiler.flex"
{ count();	return CALLMETHOD; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 178 "swf5compiler.flex"
{ count();	return AND; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 179 "swf5compiler.flex"
{ count();	return OR; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 180 "swf5compiler.flex"
{ count();	return XOR; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 181 "swf5compiler.flex"
{ count();	return MODULO; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 182 "swf5compiler.flex"
{ count();	return ADD; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 183 "swf5compiler.flex"
{ count();	return ADD; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 184 "swf5compiler.flex"
{ count();	return LESSTHAN; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 185 "swf5compiler.flex"
{ count();	return LESSTHAN; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 186 "swf5compiler.flex"
{ count();	return EQUALS; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 187 "swf5compiler.flex"
{ count();	return EQUALS; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 188 "swf5compiler.flex"
{ count();	return INC; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 189 "swf5compiler.flex"
{ count();	return DEC; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 190 "swf5compiler.flex"
{ count();	return ENUMERATE; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 191 "swf5compiler.flex"
{ count();	return INITOBJECT; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 192 "swf5compiler.flex"
{ count();	return INITARRAY; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 193 "swf5compiler.flex"
{ count();	return GETMEMBER; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 194 "swf5compiler.flex"
{ count();	return SETMEMBER; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 195 "swf5compiler.flex"
{ count();	return SHIFTLEFT; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 196 "swf5compiler.flex"
{ count();	return SHIFTRIGHT; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 197 "swf5compiler.flex"
{ count();	return SHIFTRIGHT2; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 198 "swf5compiler.flex"
{ count();	return VAREQUALS; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 199 "swf5compiler.flex"
{ count();	return OLDADD; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 200 "swf5compiler.flex"
{ count();	return SUBTRACT; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 201 "swf5compiler.flex"
{ count();	return MULTIPLY; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 202 "swf5compiler.flex"
{ count();	return DIVIDE; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 203 "swf5compiler.flex"
{ count();	return OLDEQUALS; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 204 "swf5compiler.flex"
{ count();	return OLDLESSTHAN; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 205 "swf5compiler.flex"
{ count();	return LOGICALAND; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 206 "swf5compiler.flex"
{ count();	return LOGICALOR; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 207 "swf5compiler.flex"
{ count();	return NOT; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 208 "swf5compiler.flex"
{ count();	return STRINGEQ; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 209 "swf5compiler.flex"
{ count();	return STRINGLENGTH; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 210 "swf5compiler.flex"
{ count();	return SUBSTRING; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 211 "swf5compiler.flex"
{ count();	return GETVARIABLE; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 212 "swf5compiler.flex"
{ count();	return SETVARIABLE; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 213 "swf5compiler.flex"
{ count();	return SETTARGETEXPRESSION; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 214 "swf5compiler.flex"
{ count();	return STARTDRAG; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 215 "swf5compiler.flex"
{ count();	return STOPDRAG; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 216 "swf5compiler.flex"
{ count();	return STRINGLESSTHAN; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 217 "swf5compiler.flex"
{ count();	return MBLENGTH; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 218 "swf5compiler.flex"
{ count();	return MBSUBSTRING; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 219 "swf5compiler.flex"
{ count();	return MBORD; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 220 "swf5compiler.flex"
{ count();	return MBCHR; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 221 "swf5compiler.flex"
{ count();	return BRANCHALWAYS; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 222 "swf5compiler.flex"
{ count();	return BRANCHALWAYS; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 223 "swf5compiler.flex"
{ count();	return BRANCHIFTRUE; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 224 "swf5compiler.flex"
{ count();	return POST; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 225 "swf5compiler.flex"
{ count();	return GET; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 226 "swf5compiler.flex"
{ count();	return END;		}
	YY_BREAK

case 111:
YY_RULE_SETUP
#line 229 "swf5compiler.flex"
{ count();	swf5lval.str = strdup(swf5text+2);
					return REGISTER;	}
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 233 "swf5compiler.flex"
{ count();	swf5lval.str = strdup(swf5text);
					return IDENTIFIER;	}
	YY_BREAK
case 113:
/* rule 113 can match eol */
YY_RULE_SETUP
#line 236 "swf5compiler.flex"
{ count();	swf5lval.str = strdup(swf5text+1);
					swf5lval.str[strlen(swf5lval.str)-1]=0;
                                        unescape(swf5lval.str);
					return STRING;		}
	YY_BREAK
case 114:
/* rule 114 can match eol */
YY_RULE_SETUP
#line 241 "swf5compiler.flex"
{ count();	swf5lval.str = strdup(swf5text+1);
					swf5lval.str[strlen(swf5lval.str)-1]=0;
                                        unescape(swf5lval.str);
					return STRING; 		}
	YY_BREAK
case 115:
/* rule 115 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up swf5text */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up swf5text again */
YY_RULE_SETUP
#line 246 "swf5compiler.flex"
{ count();	swf5lval.str = strdup("");
					warning("Unterminated string!");
					return STRING;		}
	YY_BREAK
case 116:
/* rule 116 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up swf5text */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up swf5text again */
YY_RULE_SETUP
#line 250 "swf5compiler.flex"
{ count();	swf5lval.str = strdup("");
					warning("Unterminated string!");
					return STRING;		}
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 254 "swf5compiler.flex"
{ count();	comment();		}
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 255 "swf5compiler.flex"
{ count();	comment1();		}
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 256 "swf5compiler.flex"
{ count(); }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 258 "swf5compiler.flex"
{ count();	return INCR; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 259 "swf5compiler.flex"
{ count();	return DECR; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 260 "swf5compiler.flex"
{ count();	return LE; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 261 "swf5compiler.flex"
{ count();	return GE; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 262 "swf5compiler.flex"
{ count();	return EQ; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 263 "swf5compiler.flex"
{ count();	return NE; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 264 "swf5compiler.flex"
{ count();	return LAN; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 265 "swf5compiler.flex"
{ count();	return LOR; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 266 "swf5compiler.flex"
{ count();	return MEQ; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 267 "swf5compiler.flex"
{ count();	return DEQ; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 268 "swf5compiler.flex"
{ count();	return IEQ; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 269 "swf5compiler.flex"
{ count();	return SEQ; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 270 "swf5compiler.flex"
{ count();	return AEQ; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 271 "swf5compiler.flex"
{ count();	return OEQ; }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 272 "swf5compiler.flex"
{ count();	return SHL; }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 273 "swf5compiler.flex"
{ count();	return SHR; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 274 "swf5compiler.flex"
{ count();	return SHR2; }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 275 "swf5compiler.flex"
{ count();	return SHLEQ; }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 276 "swf5compiler.flex"
{ count();	return SHREQ; }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 277 "swf5compiler.flex"
{ count();	return SHR2EQ; }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 279 "swf5compiler.flex"
{ count();	return '<'; }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 280 "swf5compiler.flex"
{ count();	return '>'; }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 281 "swf5compiler.flex"
{ count();	return ';'; }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 282 "swf5compiler.flex"
{ count();	return '='; }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 283 "swf5compiler.flex"
{ count();	return '+'; }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 284 "swf5compiler.flex"
{ count();	return '-'; }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 285 "swf5compiler.flex"
{ count();	return '&'; }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 286 "swf5compiler.flex"
{ count();	return '|'; }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 287 "swf5compiler.flex"
{ count();	return '^'; }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 288 "swf5compiler.flex"
{ count();	return '*'; }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 289 "swf5compiler.flex"
{ count();	return '/'; }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 290 "swf5compiler.flex"
{ count();	return '%'; }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 291 "swf5compiler.flex"
{ count();	return '!'; }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 292 "swf5compiler.flex"
{ count();	return '('; }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 293 "swf5compiler.flex"
{ count();	return ')'; }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 294 "swf5compiler.flex"
{ count();	return '['; }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 295 "swf5compiler.flex"
{ count();	return ']'; }
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 296 "swf5compiler.flex"
{ count();	return '{'; }
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 297 "swf5compiler.flex"
{ count();	BEGIN(0); return '}'; }
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 298 "swf5compiler.flex"
{ count();	return ','; }
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 299 "swf5compiler.flex"
{ count();	return '.'; }
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 300 "swf5compiler.flex"
{ count();	return '?'; }
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 301 "swf5compiler.flex"
{ count();	return ':'; }
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 302 "swf5compiler.flex"
{ count();	return '~'; }
	YY_BREAK
case 164:
/* rule 164 can match eol */
YY_RULE_SETUP
#line 304 "swf5compiler.flex"
{ count();	strcpy(szLine, swf5text + 1);
					countline();	yyless(1);	}
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 307 "swf5compiler.flex"
SWF_error("Unrecognized character: %s\n", swf5text);
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 309 "swf5compiler.flex"
ECHO;
	YY_BREAK
#line 2236 "lex.swf5.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(asm):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed swf5in at a new source and called
			 * swf5lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = swf5in;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( swf5wrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * swf5text, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of swf5lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					swf5realloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			swf5restart(swf5in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) swf5realloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 650 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 650 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 649);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up swf5text */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					swf5restart(swf5in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( swf5wrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve swf5text */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void swf5restart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        swf5ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            swf5_create_buffer(swf5in,YY_BUF_SIZE );
	}

	swf5_init_buffer(YY_CURRENT_BUFFER,input_file );
	swf5_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void swf5_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		swf5pop_buffer_state();
	 *		swf5push_buffer_state(new_buffer);
     */
	swf5ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	swf5_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (swf5wrap()) processing, but the only time this flag
	 * is looked at is after swf5wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void swf5_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	swf5in = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE swf5_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) swf5alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in swf5_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) swf5alloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in swf5_create_buffer()" );

	b->yy_is_our_buffer = 1;

	swf5_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with swf5_create_buffer()
 * 
 */
    void swf5_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		swf5free((void *) b->yy_ch_buf  );

	swf5free((void *) b  );
}

#ifndef _UNISTD_H /* assume unistd.h has isatty() for us */
#ifdef __cplusplus
extern "C" {
#endif
#ifdef __THROW /* this is a gnuism */
extern int isatty (int ) __THROW;
#else
extern int isatty (int );
#endif
#ifdef __cplusplus
}
#endif
#endif
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a swf5restart() or at EOF.
 */
    static void swf5_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	swf5_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then swf5_init_buffer was _probably_
     * called from swf5restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void swf5_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		swf5_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void swf5push_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	swf5ensure_buffer_stack();

	/* This block is copied from swf5_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from swf5_switch_to_buffer. */
	swf5_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void swf5pop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	swf5_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		swf5_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void swf5ensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)swf5alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in swf5ensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)swf5realloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in swf5ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE swf5_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) swf5alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in swf5_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	swf5_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to swf5lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       swf5_scan_bytes() instead.
 */
YY_BUFFER_STATE swf5_scan_string (yyconst char * yystr )
{
    
	return swf5_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to swf5lex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE swf5_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) swf5alloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in swf5_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = swf5_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in swf5_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up swf5text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		swf5text[swf5leng] = (yy_hold_char); \
		(yy_c_buf_p) = swf5text + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		swf5leng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int swf5get_lineno  (void)
{
        
    return swf5lineno;
}

/** Get the input stream.
 * 
 */
FILE *swf5get_in  (void)
{
        return swf5in;
}

/** Get the output stream.
 * 
 */
FILE *swf5get_out  (void)
{
        return swf5out;
}

/** Get the length of the current token.
 * 
 */
int swf5get_leng  (void)
{
        return swf5leng;
}

/** Get the current token.
 * 
 */

char *swf5get_text  (void)
{
        return swf5text;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void swf5set_lineno (int  line_number )
{
    
    swf5lineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see swf5_switch_to_buffer
 */
void swf5set_in (FILE *  in_str )
{
        swf5in = in_str ;
}

void swf5set_out (FILE *  out_str )
{
        swf5out = out_str ;
}

int swf5get_debug  (void)
{
        return swf5_flex_debug;
}

void swf5set_debug (int  bdebug )
{
        swf5_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from swf5lex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    swf5in = stdin;
    swf5out = stdout;
#else
    swf5in = (FILE *) 0;
    swf5out = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * swf5lex_init()
     */
    return 0;
}

/* swf5lex_destroy is for both reentrant and non-reentrant scanners. */
int swf5lex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		swf5_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		swf5pop_buffer_state();
	}

	/* Destroy the stack itself. */
	swf5free((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * swf5lex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *swf5alloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *swf5realloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void swf5free (void * ptr )
{
	free( (char *) ptr );	/* see swf5realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 309 "swf5compiler.flex"


static int getinput() {
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
}

int swf5wrap()
{
  return 1;
}

static void countline()
{
  if(sLineNumber != 0)
    msgline[column] = 0;

  ++sLineNumber;
  column = 0;
  msgline = msgbufs[sLineNumber & 1];
}

static int LineNumber(void)
{
   return (sLineNumber + 1);
}

static int ColumnNumber(void)
{
   return column;
}

static char *LineText(void)
{
  msgline[column] = 0;
  return msgline;
}

static void comment()
{
   // Handle block comments

   int c, c1;

loop:
   // We have the start of a comment so look skip everything up to the
   // end of the comment character
   while ((c = getinput()) != '*' && c != EOF)
   {
      if(column < 1023)
         msgline[column] = c;

      ++column;

      // keep the line number in synch
      if (c == '\n')
      {
         // start the output (matches the algorithim in the lexx above)
	 countline();
      }

      if (swf5debug) putchar(c);
   }

   // is this the end of comment character
   if ((c1 = getinput()) != '/' && c != EOF)
   {
      // false start as this was no end of comment
      do_unput5(c1);
      goto loop;
   }

   // write out the start of the end of comment
   if (c != EOF)
      if (swf5debug) putchar(c);

   // write out the end of the end of comment
   if (c1 != EOF) 
      if (swf5debug) putchar(c1);
}

static void comment1()
{
   // Handle comment of type 1 (ie '//')

   int c;

   // this is a line comment
   while ((c = getinput()) != '\n' && c != EOF)
   {
      if (swf5debug) putchar(c);

      if(column < 1023)
         msgline[column] = c;

      ++column;
   };

   // keep the line number in synch
   if (c == '\n')
   {
      if (swf5debug) putchar(c);

      countline();
   }
}

static void count(void)
{
   int n;

   // Count the characters to maintain the current column position
   if (swf5text[0] == '\n')
   {
      if (swf5debug) printf("\n");
   }
   else
   {
      if (swf5debug) printf("%s", swf5text);

      for(n=0; n<swf5leng; ++n, ++column)
      {
	if(column < 1023)
	  msgline[column] = swf5text[n];
      }

      //-- keep writing the stuff to standard output
      //column += swf5leng;
   }
}

static void printprog()
{
  if(sLineNumber)
    SWF_warn("\n%s", msgbufs[(sLineNumber-1)&1]);

  if(column < 1023)
    msgline[column] = 0;

  SWF_warn("\n%s", msgline);
}

static void warning(char *msg)
{
   // print a warning message
   printprog();
   SWF_warn("\n%*s", ColumnNumber(), "^");
   SWF_warn("\nLine %4.4d:  Reason: '%s' \n", LineNumber(), msg);
}

void swf5error(char *msg)
{
  // report a error
  if(strlen(swf5text))
  {
    SWF_error("\n%s\n%*s\nLine %i:  Reason: '%s'\n",
	      LineText(), ColumnNumber(), "^", LineNumber(), msg);
  }
  else
  {
    SWF_error("\nLine %d: Reason: 'Unexpected EOF found while looking for input.'\n", LineNumber());
  }
}

